# Fr - Python

Ceci est une tentative de traduction des classes de base Python, de certaines conditions et certaines fonctions

| Version | Etat       | Nouveauté  |
| ------- | ---------- | ---------- |
| 1.0     | Mort       |  /         |
| 1.1     | Mort       |  /         |
| 1.2     | Mort       |  /         |
| 1.2.4   | *Stable    | Utilisable |
| 1.2.5   | *Stable    | License    |
| 1.2.6   | *Stable    | /          |
| 1.2.7   | *Stable    | PyPi       |
| 1.3     | Mort       | Decimal    |
| 1.4     | En Test    | Booleen    |

*stable mais pas trop

## Documentation

La Documentation est disponible dans le fichier [DOCS.md](/DOCS.md)

Elle regroupe l'ensemble des classes et des fonctions

## Installation

Pour l'installer:

```powershell
$ pip install frpython
```

Pour installer la version de test:

```powershell
$ pip install -i https://test.pypi.org/simple/ frpython
```

Pour l'utiliser dans un script:

```py
from frpython import *
```



## Bonus Traduction des Erreurs

Si le temps le permet une traduction de certaines erreurs sera effectuée
